/*  This file is part of the KDE project
    Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
    Copyright (C) 2000 Yves Arrouye <yves@realnames.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

/* $Id: kuriikwsfilter.h,v 1.11 2001/10/27 16:32:53 hausmann Exp $ */

#ifndef __KURIIKWSFILTER_H__
#define __KURIIKWSFILTER_H__

#include <dcopobject.h>
#include <kgenericfactory.h>

#include <kurifilter.h>

class KInstance;

class KURIIKWSFilter : public KURIFilterPlugin, public DCOPObject
{
    K_DCOP
    Q_OBJECT
public:
    KURIIKWSFilter(QObject *parent = 0, const char *name = 0,
	           const QStringList &args = QStringList() );
    ~KURIIKWSFilter();

    virtual bool filterURI( KURIFilterData& ) const;

k_dcop:
    virtual void configure();
};

#endif

